@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Macro.h 2395 2007-04-01 14:28:16Z svn $
+ * $Id: Macro.h 2622 2007-11-05 16:20:54Z svn $
  *****************************************************************************/
 
 /**
@@ -59,7 +59,9 @@
 /**
  * メモリバリアです．
  */
-#ifdef __GNUC__
+#if defined(GCC_ATOMIC_BUILTINS)
+#define MEMORY_BARRIER __sync_synchronize()
+#elif defined(__GNUC__)
 #define MEMORY_BARRIER __asm__ __volatile__ ("": : :"memory")
 #else
 #define MEMORY_BARRIER
