@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Base64FileWriter.cpp 2388 2007-03-10 11:34:50Z svn $
+ * $Id: Base64FileWriter.cpp 2695 2007-11-18 13:33:50Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -34,12 +34,12 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: Base64FileWriter.cpp 2388 2007-03-10 11:34:50Z svn $");
+SOURCE_INFO_ADD("$Id: Base64FileWriter.cpp 2695 2007-11-18 13:33:50Z svn $");
 #endif
 
-#define UCHAR(c) static_cast<unsigned char>(c)
+#define BYTE(c) static_cast<apr_byte_t>(c)
 
-template<class W> const unsigned char
+template<class W> const apr_byte_t
 Base64FileWriter<W>::ALPHABET[65] =
     "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
@@ -66,25 +66,24 @@ Base64FileWriter<W>::Base64FileWriter(apr_pool_t *pool, apr_file_t *file,
  * private メソッド
  *****************************************************************************/
 template<class W>
-void Base64FileWriter<W>::write_impl(unsigned char *buffer,
-                                     apr_size_t *buffer_size)
+apr_size_t Base64FileWriter<W>::write_impl(apr_byte_t *buffer,
+                                           apr_size_t size)
 {
-    apr_size_t size;
+    apr_size_t proc_size;
     apr_size_t write_size;
-    unsigned char c;
+    apr_byte_t c;
 
-    size = *buffer_size;
     write_size = 0;
-    for (apr_size_t i = 0; i < size; i++) {
-        c = buffer[i];
+    for (proc_size = 0; proc_size < size; proc_size++) {
+        c = buffer[proc_size];
 
         if (c == '=') {
             if (decode_buffer_index_ == 2) {
-                buffer[write_size+0] = UCHAR((decode_buffer_ >> 4) & 0xff);
+                buffer[write_size+0] = BYTE((decode_buffer_ >> 4) & 0xff);
                 write_size += 1;
             } else if (decode_buffer_index_ == 3) {
-                buffer[write_size+0] = UCHAR((decode_buffer_ >> 10) & 0xff);
-                buffer[write_size+1] = UCHAR((decode_buffer_ >>  2) & 0xff);
+                buffer[write_size+0] = BYTE((decode_buffer_ >> 10) & 0xff);
+                buffer[write_size+1] = BYTE((decode_buffer_ >>  2) & 0xff);
                 write_size += 2;
             }
             break;
@@ -97,9 +96,9 @@ void Base64FileWriter<W>::write_impl(unsigned char *buffer,
         decode_buffer_index_++;
 
         if (decode_buffer_index_ == 4) {
-            buffer[write_size+0] = UCHAR((decode_buffer_ >> 16) & 0xff);
-            buffer[write_size+1] = UCHAR((decode_buffer_ >>  8) & 0xff);
-            buffer[write_size+2] = UCHAR((decode_buffer_ >>  0) & 0xff);
+            buffer[write_size+0] = BYTE((decode_buffer_ >> 16) & 0xff);
+            buffer[write_size+1] = BYTE((decode_buffer_ >>  8) & 0xff);
+            buffer[write_size+2] = BYTE((decode_buffer_ >>  0) & 0xff);
 
             write_size += 3;
 
@@ -108,8 +107,9 @@ void Base64FileWriter<W>::write_impl(unsigned char *buffer,
         }
     }
 
-    writer_impl_.write(buffer, write_size);
-    *buffer_size = write_size;
+    writer_impl_.write(buffer, &write_size);
+
+    return proc_size;
 }
 
 
@@ -117,7 +117,6 @@ void Base64FileWriter<W>::write_impl(unsigned char *buffer,
  * テスト
  *****************************************************************************/
 #ifdef DEBUG_Base64FileWriter
-#include "BasicFileWriter.h"
 
 #include "TestRunner.h"
 
@@ -147,8 +146,7 @@ void run_copy(apr_pool_t *pool,
 
     File decoded_file(pool, decoded_file_path);
     decoded_file.open(APR_CREATE|APR_TRUNCATE|APR_READ|APR_WRITE|APR_BINARY);
-    Base64FileWriter<BasicFileWriter> decoded_file_writer
-        (pool, decoded_file.get_handle());
+    Base64FileWriter<> decoded_file_writer(pool, decoded_file.get_handle());
 
     remain_size = static_cast<apr_size_t>(encoded_file.get_size()); // 4G の壁
 
