@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.cpp 2616 2007-10-29 14:50:31Z svn $
+ * $Id: DownloadFlowController.cpp 2675 2007-11-17 14:11:58Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2616 2007-10-29 14:50:31Z svn $");
+SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2675 2007-11-17 14:11:58Z svn $");
 
 const apr_size_t DownloadSession::DOWNLOAD_BUSY_SLEEP_SEC   = 5;
 
@@ -122,7 +122,7 @@ const char *DownloadFlowController::dump_list(apr_pool_t *pool,
 {
     const char *dump;
 
-    dump = apr_psprintf(pool, "%-24s : %u\n",
+    dump = apr_psprintf(pool, "%-24s : %" APR_SIZE_T_FMT "\n",
                         "total count", flow_controller->downloader_count_);
     for (apr_size_t i = 0; i < DLD_MAX_SESSION_COUNT; i++) {
         if (flow_controller->downloader_list_[i].session_count == 0) {
