@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemWriter.cpp 2296 2006-12-24 02:58:57Z svn $
+ * $Id: UploadItemWriter.cpp 2556 2007-08-12 01:36:38Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -48,7 +48,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemWriter.cpp 2296 2006-12-24 02:58:57Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemWriter.cpp 2556 2007-08-12 01:36:38Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -186,8 +186,9 @@ void UploadItemWriter::get_thumbnail_size(ImageFile *image_file,
                                           apr_size_t *width,
                                           apr_size_t *height)
 {
-    static const double THUMBAIL_ASPECT =
-        static_cast<double>(VIW_THUMBNAIL_WIDTH_LIMIT)/VIW_THUMBNAIL_HEIGHT_LIMIT;
+    static const apr_size_t ASPECT_FACTOR   = 1024;
+    static const apr_size_t THUMBAIL_ASPECT =
+        VIW_THUMBNAIL_WIDTH_LIMIT*ASPECT_FACTOR/VIW_THUMBNAIL_HEIGHT_LIMIT;
 
     *width = image_file->get_width();
     *height = image_file->get_height();
@@ -196,7 +197,7 @@ void UploadItemWriter::get_thumbnail_size(ImageFile *image_file,
         THROW(MESSAGE_POST_IMAGE_SIZE_INVALID);
     }
 
-    if ((static_cast<double>(*width)/(*height)) > THUMBAIL_ASPECT) {
+    if (((*width)*ASPECT_FACTOR/(*height)) > THUMBAIL_ASPECT) {
         // 横長の場合
         if ((*width) > VIW_THUMBNAIL_WIDTH_LIMIT) {
             *height = (*height) * VIW_THUMBNAIL_WIDTH_LIMIT / (*width);
