@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 2538 2007-07-16 15:21:45Z svn $
+ * $Id: mod_uploader.cpp 2585 2007-10-17 13:27:06Z svn $
  *****************************************************************************/
 
 /**
@@ -57,7 +57,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2538 2007-07-16 15:21:45Z svn $");
+SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2585 2007-10-17 13:27:06Z svn $");
 
 static const char *HANDLER_NAME = "uploader";
 static apr_array_header_t *uploader_config_array = NULL;
@@ -135,6 +135,7 @@ static void *uploader_create_dir_config(apr_pool_t *p, char *dirspec)
 
     new(config) UploaderConfig(p);
 
+
     memcpy(apr_array_push(uploader_config_array), &config,
            sizeof(UploaderConfig *));
 
@@ -289,6 +290,7 @@ DIRECTIVE_HANDLER(file_size_limit, apr_atoi64(arg) * 1024);
 DIRECTIVE_HANDLER(per_page_item_number, atoi(arg));
 
 TEMPLATE_DIRECTIVE_HANDLER(INDEX_VIEW, apr_pstrdup(parms->pool, arg));
+TEMPLATE_DIRECTIVE_HANDLER(INFO_VIEW, apr_pstrdup(parms->pool, arg));
 TEMPLATE_DIRECTIVE_HANDLER(PROGRESS_VIEW, apr_pstrdup(parms->pool, arg));
 TEMPLATE_DIRECTIVE_HANDLER(DOWNLOAD_VIEW, apr_pstrdup(parms->pool, arg));
 TEMPLATE_DIRECTIVE_HANDLER(THUMBNAIL_VIEW, apr_pstrdup(parms->pool, arg));
@@ -308,6 +310,7 @@ static const command_rec uploader_cmds[] = {
     DIRECTIVE_ENTRY(PER_PAGE_ITEM_NUMBER, per_page_item_number),
 
     DIRECTIVE_ENTRY(INDEX_VIEW_TEMPLATE, INDEX_VIEW),
+    DIRECTIVE_ENTRY(INFO_VIEW_TEMPLATE, INFO_VIEW),
     DIRECTIVE_ENTRY(PROGRESS_VIEW_TEMPLATE, PROGRESS_VIEW),
     DIRECTIVE_ENTRY(DOWNLOAD_VIEW_TEMPLATE, DOWNLOAD_VIEW),
     DIRECTIVE_ENTRY(THUMBNAIL_VIEW_TEMPLATE, THUMBNAIL_VIEW),
