@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2691 2007-11-18 05:45:31Z svn $
+ * $Id: uploader_handler.cpp 2705 2007-11-25 01:22:41Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2691 2007-11-18 05:45:31Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2705 2007-11-25 01:22:41Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -799,16 +799,18 @@ static int download_impl(typename Response::Handle *r, UploaderConfig *config,
     Response::set_content_disposition(r, mode);
 
 #if defined(USE_GZIP) && defined(UPLOADER_TYPE_APACHE)
-    if (!is_gzip_accepted<Response>(r)) {
-        typename Response::Writer o(r);
+    if (uitem->is_gzipped()) {
+        if (!is_gzip_accepted<Response>(r)) {
+            typename Response::Writer o(r);
 
-        return error<Response>(r, o, config, MESSAGE_DOWNLOAD_GZIP_NEEDED);
+            return error<Response>(r, o, config, MESSAGE_DOWNLOAD_GZIP_NEEDED);
+        }
+
+        // mod_deflate が動かないようにする
+        apr_table_setn(r->subprocess_env, "no-gzip", "on");
+
+        apr_table_setn(r->headers_out, "Content-Encoding", "gzip");
     }
-
-    // mod_deflate が動かないようにする
-    apr_table_setn(r->subprocess_env, "no-gzip", "no-gzip");
-
-    apr_table_setn(r->headers_out, "Content-Encoding", "gzip");
 #endif
 
     Response::header_end(r);
